@@ -1,5 +1,5 @@
 # Retrieves only metadata from pages
-Q_PAGE_META = """
+Q_PAGE_META = '''
 current_page
 has_more_pages
 from
@@ -7,4 +7,4 @@ to
 data {{
     {dataFields}
 }}
-"""
+'''
